# GORT

![Versions](https://img.shields.io/badge/python->3.10-blue)
[![Documentation Status](https://readthedocs.org/projects/lvmgort/badge/?version=latest)](https://lvmgort.readthedocs.io/en/latest/)
[![Test](https://github.com/sdss/lvmgort/actions/workflows/test.yml/badge.svg)](https://github.com/sdss/lvmgort/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/sdss/lvmgort/branch/main/graph/badge.svg)](https://codecov.io/gh/sdss/lvmgort)

[GORT (Genetically Organized Robotic Technology)](https://en.wikipedia.org/wiki/Gort_(The_Day_the_Earth_Stood_Still)) is a high-level library for remote and robotic observing with LVM.


**Documentation:** https://lvmgort.readthedocs.io/en/latest/index.html
